from setuptools import setup, find_packages

setup(
    name="zypzctest",
    version="0.0.1",
    author="PZC",
    author_email="2556616974@qq.com",
    description="This project is for testing. It doesn't have any function.",
    url="https://gitee.com/always-on-the-road-pzc/220208",
    packages=find_packages()
)
